==============================================
A bunch of Fabric commands we use all the time
==============================================

This package contains a selection of Fabric command we at NiteoWeb use all the
time. By sharing them online we hope to save someone some time researching how
certain Plone-oriented tasks are performed with Fabric. Commands contain some
hardcoded internal stuff, so they are not really usable out-of-the-box, more so
as a point of reference. If there is interest, we'll rewrite them to be more
reusable.

* `Source code @ GitHub <http://github.com/nzupan/niteoweb.fabfile>`_
* `Releases @ PyPI <http://pypi.python.org/pypi/niteoweb.fabfile>`_
* `Sphinx docs @ ReadTheDocs <http://readthedocs.org/docs/niteowebfabfile>`_
